@@ -2,10 +2,10 @@ import multiprocessing
 from typing import List, Tuple
 
 import jstyleson
+import psutil
 
 from manytasks import shared
 from manytasks.shared import Arg, Task
-import psutil
 
 
 def next_config_idx(configs, config_idx):
@@ -112,10 +112,10 @@ def load_config(path="sample_config.json"):
     cuda = config["cuda"]
     if cuda == [] or cuda == -1:
         cuda = [-1]
-    else:
-        if psutil.WINDOWS:
-            print("CUDA shoule be -1 on windows")
-            exit()
+    
+    if cuda[0] != -1 and psutil.WINDOWS:
+        print("CUDA shoule be -1 on windows")
+        exit()
     shared.cuda = cuda
     
 
@@ -127,6 +127,8 @@ def load_config(path="sample_config.json"):
             print("You must specify which CUDA devices you want to use if concurrency is set to #CUDA.")
     elif concurrency == "#CPU":
         concurrency = max(1, multiprocessing.cpu_count() - 1)
+    else:
+        concurrency = int(concurrency)
     shared.concurrency = concurrency
     
     base_conf = parse_config(config["configs"]["==base=="])
